# coding:utf-8

from urllib.parse import urljoin

__project__ = "xpip.upload"
__version__ = "1.1"
__description__ = "upload python package via twine"
__url_home__ = "https://github.com/bondbox/xpip/"
__url_code__ = __url_home__
__url_docs__ = __url_home__
__url_bugs__ = urljoin(__url_home__, "issues")

# author
__author__ = "Mingzhe Zou"
__author_email__ = "zoumingzhe@outlook.com"
